@@ -144,7 +144,6 @@ int main(int argc, char *argv[])
 		if (signal(signals[i], handler) == SIG_ERR)
 			fprintf(stderr, "%s: cannot set handler for signal %d: %m\n", PACKAGE_NAME, signals[i]);
 
-	assert(curl_errmsg);
 	memset(curl_errmsg, 0, CURL_ERROR_SIZE);
 	curl_global_init(CURL_GLOBAL_NOTHING);
 	curl = curl_easy_init();
@@ -158,7 +157,9 @@ int main(int argc, char *argv[])
 		curl_easy_setopt(curl, CURLOPT_HEADERFUNCTION, curl_callback) != CURLE_OK ||
 		curl_easy_setopt(curl, CURLOPT_WRITEHEADER, (void*)&header) != CURLE_OK ||
 		(proxy && curl_easy_setopt(curl, CURLOPT_PROXY, proxy) != CURLE_OK) ||
-		(proxy && proxy_user && curl_easy_setopt(curl, CURLOPT_PROXYUSERPWD, proxy_user) != CURLE_OK)) {
+		(proxy && proxy_user && curl_easy_setopt(curl, CURLOPT_PROXYUSERPWD, proxy_user) != CURLE_OK) ||
+		curl_easy_setopt(curl, CURLOPT_FOLLOWLOCATION, 1) != CURLE_OK ||
+		curl_easy_setopt(curl, CURLOPT_MAXREDIRS, 10) != CURLE_OK) {
 		fprintf(stderr, "%s: %s\n", PACKAGE_NAME, curl_errmsg);
 		exit(1);
 	}
